###DOmake.wind.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
## Modif J.S.Charters Jun99 mlvl62 Change in ins_met
## Modif J.S.Charters Jan00 revelle, add units of ship speed
## Modif D.J. 2003Jan05: (1) now CD to TRANS dir for data. 
##			 (2) IFN from met_filename
##			 (3) draws data from ins_met reading *.MET file
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.wind.page.plot   <date.ext>"
   echo " (produces profile ps file named metfile.<date.ext>.ps)"
   exit
endif

# Change these Lower/Upper ranges as necessary:

set WIND_SPD_RANGE = 15/40
set WIND_SPD_TIC = "a2g2f1:Wind Speed"

set WIND_DIR_RANGE = 0/360
set WIND_DIR_TIC = "a60g30f15:Wind Dir"

set SHIP_DIR_RANGE = 0/360
set SHIP_DIR_TIC = "a60g30f15:Ship Dir:"

set SHIP_SPD_RANGE = 0/360
set SHIP_SPD_TIC = "a2g2f1:Ship Speed(m/s):"


# Don't change these:
set HR_RANGE       = 0./24.
set HR_TIC       = "2g1::"

cd $DIRUWDATA/TRANS

set DATE = $1

set IFN = `$BINDIR/met_filename $DATE`

# test for a compressed file if exists then uncompress it
if ( -e $IFN.Z) then
	uncompress $IFN
endif

# test for the data file to exist
if !( -e $IFN) then
	echo "DOmake.wind.page.plot: No data file: $IFN"
	exit
endif

#test for any data to process
#grep ^METWND $IFN > /dev/null
#if ( $status == 1) then
#	compress -f $IFN
#	exit
#endif

###################################################

set PAGE_SIZE = letter

set OFN = WIND.$IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.1
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.5
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "Wind Data $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

/usr/local/bin/ins/ins_met < $IFN > all_data
 
###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`


###################### start 1st panel ######################################
#
# Wind Speed relative

$BINDIR/met_ins_data.awk field=12 scale=10 all_data > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_SPD_TIC(Relative):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M -S"$SYMB"

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################
# Wind direction relative

$BINDIR/met_ins_data.awk field=13 scale=20 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WIND_DIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_DIR_TIC(Relative):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 3nd panel ######################################
#true speed
$BINDIR/met_ins_data.awk field=14 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_SPD_TIC(True):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 4nd panel ######################################
# true direction

$BINDIR/met_ins_data.awk field=15 scale=20 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WIND_DIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$WIND_DIR_TIC(True):"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#
###################### start 5nd panel ######################################
#ship speed
$BINDIR/met_ins_data.awk field=4 scale=10 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$SHIP_SPD_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

###################### start 6nd panel ######################################
#ship dir

$BINDIR/met_ins_data.awk field=3 scale=20 all_data > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WIND_DIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$SHIP_DIR_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#
psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
####################### end panel ############################################
#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
#lpr -Php8000 $OFN
lp -d hp8000 $OFN

#
# Remove work files
#
/bin/rm -f all_data range 2col
#compress files:
compress -f $IFN
#end
